==> 1.0.0.tar.gz: web/default/project/default_project_web.dart <==

/*
http://opensource.org/licenses/

http://en.wikipedia.org/wiki/BSD_license
3-clause license ("New BSD License" or "Modified BSD License")

Copyright (c) 2012, Dartling project authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the Dartling nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

import 'dart:html';

import 'package:dartling/dartling.dart';
import 'package:dartling_default_app/dartling_default_app.dart';

import 'package:dartling_default_app/default_project.dart';

initDefaultData(DefaultRepo defaultRepo) {
   var defaultModels =
       defaultRepo.getDomainModels(DefaultRepo.defaultDomainCode);

   var defaultProjectEntries =
       defaultModels.getModelEntries(DefaultRepo.defaultProjectModelCode);
   initDefaultProject(defaultProjectEntries);
   defaultProjectEntries.display();
   defaultProjectEntries.displayJson();
}

showDefaultData(DefaultRepo defaultRepo) {
  var mainView = new View(document, "main");
  mainView.repo = defaultRepo;
  new RepoMainSection(mainView);
}

void main() {
  var defaultRepo = new DefaultRepo();
  initDefaultData(defaultRepo);
  showDefaultData(defaultRepo);
}

==> 2.0.1.tar.gz: web/default/project/default_project_web.dart <==

/*
http://opensource.org/licenses/

http://en.wikipedia.org/wiki/BSD_license
3-clause license ("New BSD License" or "Modified BSD License")

Copyright (c) 2012, Dartling project authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the Dartling nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

import 'dart:html';

import 'package:dartling_default_app/dartling_default_app.dart';

import 'package:dartling_default_app/default_project.dart';

initDefaultData(DefaultRepo defaultRepo) {
   var defaultModels =
       defaultRepo.getDomainModels(DefaultRepo.defaultDomainCode);

   var defaultProjectEntries =
       defaultModels.getModelEntries(DefaultRepo.defaultProjectModelCode);
   initDefaultProject(defaultProjectEntries);
   //defaultProjectEntries.display();
}

showDefaultData(DefaultRepo defaultRepo) {
  var mainView = new View(document, "main");
  mainView.repo = defaultRepo;
  new RepoMainSection(mainView);
}

void main() {
  var defaultRepo = new DefaultRepo();
  initDefaultData(defaultRepo);
  showDefaultData(defaultRepo);
}
